==> eea.workflow-1.7.zip: eea.workflow-1.7/eea/workflow/interfaces.py <==
from zope.interface import Interface, Attribute
#from zope.schema import List, Dict, TextLine, Object


class IHasMandatoryWorkflowFields(Interface):
    """Marker interface for objects with fields that are required for workflow transitions"""


class IValueProvider(Interface):
    """Objects of this type provide values

    The use case is this: we want to be able to interrogate various AT fields contained
    in objects if they have value; we don't want to hardcode the logic that achieves
    this, so we make it extendible by adaptation. This package also provides a default
    implementation for a component that adapts AT fields -> IValueProvider
    """

    def has_value(kwargs):
        """Returns True if the object has a value"""

    def get_value(kwargs):
        """Returns the value of this object"""


class IFieldIsRequiredForState(Interface):
    #TODO: the naming of this interface should be changed, it's too specific;
    """Objects of this type provide required for state

    The use case is this: we want to be able to interrogate various AT fields contained
    in objects if they are required for a specific state;
    we don't want to hardcode the logic that achieves this, so we make it
    extendible by adaptation. This package also provides a default
    implementation for a component that adapts AT fields -> IRequiredFor
    """
    def __call__(state):
        """ Is required for state?
        """


class IObjectReadiness(Interface):
    """Returns info on how ready is an object to be moved to a certain workflow state"""

    checks = Attribute("A mapping of workflow state to lists of checks that need to be executed")
    depends_on = Attribute("A list of objects whose readiness should be considered")

    def get_info_for(state_name):
        """Returns a mapping containing statistics on object readiness for a certain state"""

    def is_ready_for(state_name):
        """Returns a bool that tells is the object is ready to be transitioned to the named state"""

==> eea.workflow-1.10.zip: eea.workflow-1.10/eea/workflow/interfaces.py <==
from zope.interface import Interface, Attribute
#from zope.schema import List, Dict, TextLine, Object


class IHasMandatoryWorkflowFields(Interface):
    """Marker interface for objects with fields that are required for workflow transitions"""


class IValueProvider(Interface):
    """Objects of this type provide values

    The use case is this: we want to be able to interrogate various AT fields contained
    in objects if they have value; we don't want to hardcode the logic that achieves
    this, so we make it extendible by adaptation. This package also provides a default
    implementation for a component that adapts AT fields -> IValueProvider
    """

    def has_value(kwargs): #pyflakes, #pylint: disable-msg = E0213
        """Returns True if the object has a value"""

    def get_value(kwargs): #pyflakes, #pylint: disable-msg = E0213
        """Returns the value of this object"""


class IFieldIsRequiredForState(Interface):
    ###c the naming of this interface should be changed, it's too specific;
    """Objects of this type provide required for state

    The use case is this: we want to be able to interrogate various AT fields contained
    in objects if they are required for a specific state;
    we don't want to hardcode the logic that achieves this, so we make it
    extendible by adaptation. This package also provides a default
    implementation for a component that adapts AT fields -> IRequiredFor
    """
    def __call__(state): #pyflakes, #pylint: disable-msg = E0213
        """ Is required for state?
        """


class IObjectReadiness(Interface):
    """Returns info on how ready is an object to be moved to a certain workflow state"""

    checks = Attribute("A mapping of workflow state to lists of checks that need to be executed")
    depends_on = Attribute("A list of objects whose readiness should be considered")

    def get_info_for(state_name): #pyflakes, #pylint: disable-msg = E0213
        """Returns a mapping containing statistics on object readiness for a certain state"""

    def is_ready_for(state_name): #pyflakes, #pylint: disable-msg = E0213
        """Returns a bool that tells is the object is ready to be transitioned to the named state"""
